<?php
namespace Pinpoint\CarouselManager\Controller\Adminhtml\Carousel;

use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;
use Pinpoint\CarouselManager\Model\CarouselRepository;

/**
 * Class Delete
 * @package Pinpoint\CarouselManager\Controller\Adminhtml\Carousel
 */
class Delete extends Action
{
    /**
     * Authorization level of a basic admin session
     *
     * @see _isAllowed()
     */
    const ADMIN_RESOURCE = 'Pinpoint_CarouselManager::carousel';

    /**
     * @var CarouselRepository
     */
    protected $carouselRepository;

    /**
     * Delete constructor.
     * @param CarouselRepository $carouselRepository
     * @param Context $context
     */
    public function __construct(
        Context $context,
        CarouselRepository $carouselRepository
    ) {
        $this->carouselRepository = $carouselRepository;
        parent::__construct($context);
    }

    /**
     * @return mixed
     */
    public function execute()
    {
        // check if we know what should be deleted
        $id = $this->getRequest()->getParam('object_id');
        /** @var \Magento\Backend\Model\View\Result\Redirect $resultRedirect */
        $resultRedirect = $this->resultRedirectFactory->create();
        if ($id) {
            try {
                // init model and delete
                $this->carouselRepository->deleteById($id);
                // display success message
                $this->messageManager->addSuccessMessage(__('You have deleted the Carousel.'));
                // go to grid
                return $resultRedirect->setPath('*/*/');
            } catch (\Exception $e) {
                // display error message
                $this->messageManager->addErrorMessage($e->getMessage());
                // go back to edit form
                return $resultRedirect->setPath('*/*/edit', ['pinpoint_carouselmanager_carousel_id' => $id]);
            }
        }
        // display error message
        $this->messageManager->addErrorMessage(__('We can not find an object to delete.'));
        // go to grid
        return $resultRedirect->setPath('*/*/');
        
    }    
    
}
